@@ -16,6 +16,9 @@ class DatabaseEncrypted(Exception):
 class SaveData(Exception):
     pass
 
+class PathError(Exception):
+    pass
+
 def messagesTreatment(client):
     global server_is_running
     global editando
@@ -333,6 +336,7 @@ def update_infodb(valor_atualizar, just_append=True, path_dir_=None, antiblock=F
                         current = dict_saved_in_db[path_in_list]
                     elif qntd_infos_path - contador_exect == 0:
                         current[path_in_list] = valor_atualizar
+                        
                     else:
                         current = current[path_in_list]
                     contador_exect += 1
@@ -343,7 +347,8 @@ def update_infodb(valor_atualizar, just_append=True, path_dir_=None, antiblock=F
             if antiblock == False:
                 editando = False
         elif just_append == True:
-            if type(valor_atualizar) == dict:
+            resultado_volta_db = dirfdb(antiblock=True)
+            if type(valor_atualizar) == dict and type(resultado_volta_db) != str:
                 temp_list = list()
                 temp_list = path_dir[:]
                 path_dir_backup = path_dir[:]
@@ -373,9 +378,10 @@ def inicia_localdb(path_db_local_local, key_local_db_db=b'', token_drop_local=''
     inicia_db(path_to_jsontiny=path_db_local_local, key_decript=key_local_db_db, token_drop=token_drop_local)
 
 def inicia_client(ip_to_connect, port_to_connect, key_to_verify):
-    global sleep, dumps, loads, socket
+    global sleep, dumps, loads, socket, literal_eval
     from time import sleep
     from json import dumps, loads
+    from ast import literal_eval
     import socket
     key_decoded = key_to_verify.decode('utf-8')
     client = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
@@ -593,8 +599,12 @@ def dirfdb(searchdb=None, antiblock=False, path_dir_=None, return_pathed=True):
         resp = str(client.recv(2048).decode('utf-8'))
         if resp[0] == '{':
             return str_to_dict(resp)
-        else:
+        elif resp[0] == '[':
+            return str_to_list(resp)
+        elif resp == 'Empty' or resp == 'None':
             return None
+        else:
+            return resp
     else:
         if antiblock == False:
             while editando:
@@ -708,6 +718,12 @@ def remove_infodb(path_delete=None, path_dir_=None, antiblock=False):
                 raise PathListEmpty('List that contains path to update db must not be empty!')
         if type(path_delete) != list:
             raise TypeError('Path to delete must be a list!')
+        db_returned = dirfdb(antiblock=True, return_pathed=False)
+        for item_path_temp in path_dir:
+            try:
+                db_returned = db_returned[item_path_temp]
+            except:
+                raise PathError('Path to delete doesnt exists! Verify them!')
         global contador_exec
         db_delete = dirfdb(antiblock=True, return_pathed=False)
         if db_delete == None:
